@@ -342,9 +342,10 @@ def handle_exception(start_response, out_f, content_type, code=None, reason=None
 
 def open_with_autosave(db, cfg_path, cfg):
     def _inner(*args, **kwargs):
-        db.open(*args, **kwargs)
+        res = db.open(*args, **kwargs)
         if cfg.get('auto_save') and cfg.get('db_path') != db.path:
             cfg['db_path'] = db.path
             with open(cfg_path, 'w') as f:
                 f.write(json.dumps(cfg, sort_keys=True, indent=4))
+        return res
     return _inner
